package models

import (
	_ "github.com/go-sql-driver/mysql"
	"hongze/hongze_task/models/company_approval"
	"hongze/hongze_task/models/company_contract"
	"hongze/hongze_task/models/data_manage"
	"hongze/hongze_task/models/roadshow"
	"hongze/hongze_task/models/yb"
	"hongze/hongze_task/utils"
	"time"

	"github.com/beego/beego/v2/client/orm"
)

func init() {

	_ = orm.RegisterDataBase("default", "mysql", utils.MYSQL_URL)
	orm.SetMaxIdleConns("default", 50)
	orm.SetMaxOpenConns("default", 100)

	db, _ := orm.GetDB("default")
	db.SetConnMaxLifetime(10 * time.Minute)

	_ = orm.RegisterDataBase("rddp", "mysql", utils.MYSQL_URL_RDDP)
	orm.SetMaxIdleConns("rddp", 50)
	orm.SetMaxOpenConns("rddp", 100)

	report_db, _ := orm.GetDB("rddp")
	report_db.SetConnMaxLifetime(10 * time.Minute)

	_ = orm.RegisterDataBase("edb", "mysql", utils.MYSQL_URL_EDB)
	orm.SetMaxIdleConns("edb", 50)
	orm.SetMaxOpenConns("edb", 100)

	edb_db, _ := orm.GetDB("edb")
	edb_db.SetConnMaxLifetime(10 * time.Minute)

	_ = orm.RegisterDataBase("data", "mysql", utils.MYSQL_URL_DATA)
	orm.SetMaxIdleConns("data", 50)
	orm.SetMaxOpenConns("data", 100)

	data_db, _ := orm.GetDB("data")
	data_db.SetConnMaxLifetime(10 * time.Minute)

	_ = orm.RegisterDataBase("gl", "mysql", utils.MYSQL_URL_GL)
	orm.SetMaxIdleConns("gl", 50)
	orm.SetMaxOpenConns("gl", 100)

	gl, _ := orm.GetDB("gl")
	gl.SetConnMaxLifetime(10 * time.Minute)

	orm.Debug = true
	orm.DebugLog = orm.NewLog(utils.Binlog)

	//注册对象
	orm.RegisterModel(
		new(EdbinfoSendMsgRecord),
		new(StackCompanyStatistic),
		new(company_contract.CompanyContract),
		new(company_contract.CompanyContractPermission),
		new(company_approval.CompanyApproval),
		new(Classify),
		new(ReportSendThsDetail),
		new(Report),
		new(UserViewStatistics),
		new(roadshow.RsReportRecord), //路演记录
		new(CompanyReportRecord),
		new(ChartPermission), // 权限表
	)

	// 注册客户信息 数据表
	initCompany()

	// 注册Edb指标 数据表
	initEdbDataTable()

	// 注册研报 数据表
	initYbTable()
}

// initCompany 注册客户信息 数据表
func initCompany() {
	//注册对象
	orm.RegisterModel(
		new(Company),
		new(CompanyReportPermission),
		new(CompanyReportPermissionLog),
		new(CompanyOperationRecord),
		new(CompanyProduct),
		new(CompanyPermissionLog),
		new(CompanyEndDate),
		new(CompanyProductUpdateLog), //客户产品状态变更表
		new(CompanyViewStatistics),
	)
}

// initEdbDataTable 注册Edb指标 数据表
func initEdbDataTable() {
	//注册对象
	orm.RegisterModel(
		new(DataSourceLongzhong),
		new(Longzhonginfo),
		new(Longzhongdata),
		new(EdbdataClassify),
		new(Longzhongpriceinfo),
		new(Longzhongpricedata),
		new(LongzhongSurveyProduct),
		new(LongzhongSurveyData),
		new(data_manage.EdbDataWind),
		new(data_manage.EdbDataThs),
		new(data_manage.EdbDataPb),
		new(data_manage.BaseFromSmm),
		new(data_manage.BaseFromSmmIndex),
		new(data_manage.BaseFromSmmData),
		new(data_manage.EdbDataYs),
		new(Edbdata),
		new(data_manage.EdbInfoCalculateMapping),
		new(data_manage.EdbInfo),                 //hz_data库的edb_info表
		new(data_manage.EdbDataCalculateZjpj),    //直接拼接
		new(data_manage.EdbDataCalculateLjztbpj), //累计同比值拼接
		new(data_manage.EdbDataLt),               //路透指标数据表
		new(VarietyClassify),                     // 标签分类表
		new(VarietyTag),                          // 标签表
		new(ResearchVarietyTagRelation),          // 研究员标签关系表
	)
}

// initYbTable 注册ETA表格 数据表
func initYbTable() {
	//注册对象
	orm.RegisterModel(
		new(yb.Activity),         // 研报活动表
		new(yb.ActivityType),     //研报活动分类表
		new(yb.ActivityVoice),    //研报活动语音表
		new(yb.ActivityRegister), //研报活动报名表
		new(yb.Speaker),          //研报主持人表
		new(yb.PriceDriven),      // 研报价格驱动表
		new(yb.ComeinEvent),      //进门会议表
		new(yb.ComeinEventUser),  //进门会议用户表
		new(yb.CommunityVideo),   //研报视频社区
		new(yb.VoiceBroadcast),   // 语音播报
	)
}
